![](sgid-logo.png)

# sgid-client-python

The official Python client for sgID.

## Installation

```bash
pip install sgid-client
```

## Quick start

Refer to our developer documentation for one of our [framework-specific guides](https://docs.id.gov.sg/integrations-with-sgid/python/framework-guides), or check out the [quick start](https://docs.id.gov.sg/integrations-with-sgid/python#quick-start).

## API reference

Refer to the [API reference in our developer documentation](https://docs.id.gov.sg/integrations-with-sgid/python/api-reference).

## Supported Runtime and Environment

Python >=3.11

## For contributors

### Running tests

To run the tests locally,

1. [Install Poetry](https://python-poetry.org/docs/#installation).
2. Run the following:

```bash
poetry run pytest
```
